<?php if ( ! defined( 'ABSPATH' ) ) exit;

$ddomnus_notices = array();
$theme = wp_get_theme();
if ($theme->name !== 'Divi' && wp_get_theme()->Template !== 'Divi') {
	$ddomnus_notices[] = array(
		'message' 		=> __( 'DiviMenus on Media needs Divi to function', 'divimenus-on-media' ),
		'type' 			=> 'warning',
		'dismissible' 	=> true
	);
} else if (!in_array( 'divimenus/divimenus.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
	$ddomnus_notices[] = array(
		'message' 		=> __('Please install and activate DiviMenus in order to use DiviMenus on Media', 'divimenus-on-media'),
		'type' 			=> 'error',
		'dismissible' 	=> false
	);
} 

function ddomenus_admin_notices() {
    global $ddomnus_notices;
	if ( ! current_user_can( 'manage_options' ) )
		return;

	$screen = get_current_screen();
	if ( in_array( $screen->base, array( 'plugins', 'dashboard' )) ) {
		foreach ($ddomnus_notices as $notice) {
			printf('<div class="notice notice-%2$s%3$s"><p>%1$s</p></div>', $notice['message'], $notice['type'], $notice['dismissible'] ? ' is-dismissible' : '');
		}
	}
}	
add_action( 'admin_notices', 'ddomenus_admin_notices' );

if (empty( $ddomnus_notices )) {
	// DonDivi
	function ddomenus_plugins_loaded() {
		if (function_exists( 'dondivi_add_plugin' ))
			dondivi_add_plugin('DIVIMENUS_ON_MEDIA_DD_ADMIN', 'DiviMenus On Media', 'divimenus-on-media', DIVIMENUS_ON_MEDIA_VERSION, DIVIMENUS_ON_MEDIA_PLUGIN_PATH, true, 'divimenus-on-media', 0);
	}
	add_action( 'plugins_loaded', 'ddomenus_plugins_loaded', 11); // fires after DMs plugins loaded
	
	// DiviMenus On Media
	require_once dirname(__FILE__) . '/functions.php';

	function ddomenus_init() {
		load_plugin_textdomain( 'divimenus-on-media', false, 'divimenus-on-media/languages' ); 
	}
	add_action( 'init', 'ddomenus_init');

	function ddomenus_enqueue_scripts($hook) {
        wp_enqueue_script( 'divimenus-on-media', DIVIMENUS_ON_MEDIA_PLUGIN_DIR_URL . 'scripts/frontend-bundle.min.js', array( 'jquery' ), true, true );
        wp_enqueue_style ( 'divimenus-on-media', DIVIMENUS_ON_MEDIA_PLUGIN_DIR_URL . 'style/style.min.css' );
    }
	add_action( 'wp_enqueue_scripts', 'ddomenus_enqueue_scripts', 11 );	
	
	function ddomenus_extensions_init() {

		$modules = array('et_pb_image', 'et_pb_fullwidth_image', 'et_pb_gallery', 'et_pb_video', 'et_pb_slider', 'et_pb_fullwidth_slider', 'et_pb_post_slider', 'et_pb_fullwidth_post_slider',
		'et_pb_blog', 'et_pb_portfolio', 'et_pb_fullwidth_portfolio', 'et_pb_filterable_portfolio', 'et_pb_shop');
		
		function ddomenus_add_overlay_fields( $toggle_slug ) {
			$divimenus = array();
			$divimenus[] = __('-- Select --', 'divimenus-on-media');
			$layouts = get_posts(array('post_type'=>'et_pb_layout', 'numberposts' => -1));
			foreach ($layouts as $layout) {
				if (substr( $layout->post_content, 0, 16 ) !== "[et_pb_divimenus") {
					continue;
				}			
				$divimenus[$layout->ID] = $layout->post_title;
			}
			return array (
				'use_divimenu_overlay' => array(
					'label'           	=> esc_html__( 'DiviMenu On Media', 'divimenus-on-media' ),
					'type'            	=> 'yes_no_button',
					'options'         	=> array(
						'on'  => esc_html__( 'On', 'et_builder' ),
						'off' => esc_html__( 'Off', 'et_builder' ),					
					),
					'affects' => array(
						'divimenu_overlay',
						'divimenu_show',
						'divimenu_location',
						'divimenu_overlay_color'
					), 
					'toggle_slug'       => $toggle_slug,
					'tab_slug'  		=> 'advanced',
				),
				'divimenu_overlay' => array(
					'label'           	=> esc_html__( 'DiviMenu', 'divimenus-on-media' ),
					'type'            	=> 'select',
					'options'			=> 	$divimenus,
					'default_on_front'  =>  key($divimenus),
					'depends_show_if'   => 'on',
					'searchable'       	=> true,
					'displayRecent'    	=> false,
					'toggle_slug'       => $toggle_slug,
					'tab_slug'  		=> 'advanced',			
				),
				'divimenu_show' => array(
					'label'           	=> esc_html__( 'Display', 'divimenus-on-media' ),
					'type'            	=> 'select',
					'options'			=> 	array (
						'hover'     => esc_html__('Hover', 'divimenus-on-media'),
						'always'    => esc_html__('Always', 'divimenus-on-media'),
						'hide'    	=> esc_html__('Hide', 'divimenus-on-media'),
					),
					'default_on_front'  => 'hover',
					'mobile_options'    => true,
					'toggle_slug'       => $toggle_slug,
					'tab_slug'  		=> 'advanced',
				),
				'divimenu_location' => array(
					'label'           	=> esc_html__( 'DiviMenu Location', 'divimenus-on-media' ),
					'type'            	=> 'select',
					'options'			=> 	array (
						'tl'    => esc_html__('Top Left', 'divimenus-on-media'),
						'tc'    => esc_html__('Top Center', 'divimenus-on-media'),
						'tr'    => esc_html__('Top Right', 'divimenus-on-media'),
						'ml'    => esc_html__('Middle Left', 'divimenus-on-media'),
						'mc'    => esc_html__('Middle Center', 'divimenus-on-media'),
						'mr'    => esc_html__('Middle Right', 'divimenus-on-media'),
						'bl'    => esc_html__('Bottom Left', 'divimenus-on-media'),
						'bc'    => esc_html__('Bottom Center', 'divimenus-on-media'),
						'br'    => esc_html__('Bottom Right', 'divimenus-on-media'),
					),
					'default_on_front'  => 'mc',
					'depends_show_if'   => 'on',
					'toggle_slug'       => $toggle_slug,
					'tab_slug'  		=> 'advanced',			
				),
				'divimenu_overlay_color' => array(
					'label'             => esc_html__( 'Overlay Color', 'divimenus-on-media' ),
					'type'              => 'color-alpha',
					'custom_color'      => true,
					'default'			=> 'transparent',
					'depends_show_if'   => 'on',
					'hover'				=> 'tabs',	
					'tab_slug'          => 'advanced',
					'toggle_slug'       => $toggle_slug,
					'description'       => esc_html__( 'Here you can define a custom color for the overlay', 'et_builder' ),
				),
			);
		}
		function ddomenus_add_blurb_overlay_toggle( $fields_unprocessed ) {
			$fields_unprocessed = array_merge($fields_unprocessed, ddomenus_add_overlay_fields('icon_settings'));
			$fields_unprocessed['use_divimenu_overlay']['show_if_not'] = array('use_icon' => 'on');
			return $fields_unprocessed;
		}
		function ddomenus_add_video_slider_overlay_toggle( $fields_unprocessed ) {
			return array_merge($fields_unprocessed, ddomenus_add_overlay_fields('colors'));
		}

		function ddomenus_add_overlay_toggle( $fields_unprocessed) {
			return array_merge($fields_unprocessed, ddomenus_add_overlay_fields('overlay'));
		}

		foreach ($modules as $module) {
			add_filter( "et_pb_all_fields_unprocessed_{$module}", 'ddomenus_add_overlay_toggle');
		}	
		add_filter( 'et_pb_all_fields_unprocessed_et_pb_blurb', 'ddomenus_add_blurb_overlay_toggle');
		add_filter( 'et_pb_all_fields_unprocessed_et_pb_video_slider', 'ddomenus_add_video_slider_overlay_toggle');
		
		function ddomenus_add_overlay_options($fields_unprocessed) {
			$fields_unprocessed['link_type']['options']['on_media'] = esc_html__( 'On Media', 'divimenus-on-media' );
			$fields_unprocessed['on_media'] = array( 
					'label'           	=> esc_html__( 'On Media', 'divimenus-on-media' ),
					'type'            	=> 'select',
					'options'			=> 	array (
						'lightbox'	=> esc_html__('Open in Lightbox', 'divimenus-on-media'),
						'open'  	=> esc_html__('Open Media Link', 'divimenus-on-media'),
						'download'  => esc_html__('Download Media File', 'divimenus-on-media'),
					),
					'default_on_front'  => 'lightbox',
					'show_if'           => array( 'link_type' => 'on_media'),
					'description'		=> esc_html__('Open in Lightbox: Open the image or video in lightbox (default)<br>Open Media Link: Open the image or video link in a new tab<br>Download Media File: Download the image or video (external video URLs will be open in a new tab)', 'divimenus-on-media'), 
					'toggle_slug'     	=> 'item_link',
				
			);
			return $fields_unprocessed;
		}
		add_filter( 'et_pb_all_fields_unprocessed_et_pb_divimenus_item', 'ddomenus_add_overlay_options');

		function ddomenus_render_overlay ($output, $render_slug, $module) {
			if (isset($_GET['et_fb']) || is_array($output)) return $output;	
			if (isset($module->props['use_divimenu_overlay']) && $module->props['use_divimenu_overlay'] === 'on') {
				return ddomenus_module_output($output, $render_slug, $module);
			}
			return $output;		
		}
		add_filter('et_module_shortcode_output', 'ddomenus_render_overlay', 11, 3);
		
		function ddomenus_render_classname ($output, $render_slug, $module) {
			if ($render_slug !== 'et_pb_divimenus_item' || isset($_GET['et_fb']) || is_array($output)) return $output;
			if ($module->props['link_type'] === 'on_media' && $module->props['on_media'] === 'lightbox') {
				//$module->add_classname( 'divimenus-item-lightbox' );
				$output = str_replace('class="et_pb_divimenus_item', 'class="et_pb_divimenus_item divimenus-item-lightbox', $output);
			}
			if ($module->props['link_type'] === 'on_media' && $module->props['on_media'] === 'download') {
				//$module->add_classname( 'dd-download' );
				$output = str_replace('class="et_pb_divimenus_item', 'class="et_pb_divimenus_item dd-download', $output);
			}
			if ($module->props['link_type'] === 'on_media' && $module->props['on_media'] === 'open') {
				//$module->add_classname( 'dd-open-url' );
				$output = str_replace('class="et_pb_divimenus_item', 'class="et_pb_divimenus_item dd-open-url', $output);
			}
			return $output;
		}
		add_filter('et_module_shortcode_output', 'ddomenus_render_classname', 11, 3);
	}
	add_action( 'divi_extensions_init', 'ddomenus_extensions_init' );
}